<a id="mypy-boto3-dms"></a>

# mypy-boto3-dms

[![PyPI - mypy-boto3-dms](https://img.shields.io/pypi/v/mypy-boto3-dms.svg?color=blue)](https://pypi.org/project/mypy-boto3-dms)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-dms.svg?color=blue)](https://pypi.org/project/mypy-boto3-dms)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-dms?color=blue)](https://pypistats.org/packages/mypy-boto3-dms)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.DatabaseMigrationService 1.17.101](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/dms.html#DatabaseMigrationService)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-buider 4.21.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-dms docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dms/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-dms](#mypy-boto3-dms)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

Install `boto3-stubs` for `DatabaseMigrationService` service.

```bash
python -m pip install boto3-stubs[dms]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[dms]` in your environment:
  `python -m pip install 'boto3-stubs[dms]'`

Both type checking and auto-complete should work for `DatabaseMigrationService`
service. No explicit type annotations required, write your `boto3` code as
usual.

<a id="pycharm"></a>

### PyCharm

- Install `boto-stubs[dms]` in your environment:
  `python -m pip install 'boto3-stubs[dms]'`

Both type checking and auto-complete should work for `DatabaseMigrationService`
service. No explicit type annotations required, write your `boto3` code as
usual. Auto-complete can be slow on big projects or if you have a lot of
installed `boto3-stubs` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[dms]` in your environment:
  `python -m pip install 'boto3-stubs[dms]'`
- Run `mypy` as usual

Type checking should work for `DatabaseMigrationService` service. No explicit
type annotations required, write your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[dms]` in your environment:
  `python -m pip install 'boto3-stubs[dms]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `DatabaseMigrationService` service. No explicit
type annotations required, write your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`DatabaseMigrationServiceClient` provides annotations for
`boto3.client("dms")`.

```python
import boto3

from mypy_boto3_dms import DatabaseMigrationServiceClient

client: DatabaseMigrationServiceClient = boto3.client("dms")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: DatabaseMigrationServiceClient = session.client("dms")
```

<a id="paginators-annotations"></a>

### Paginators annotations

`mypy_boto3_dms.paginator` module contains type annotations for all paginators.

```python
from mypy_boto3_dms import DatabaseMigrationServiceClient
from mypy_boto3_dms.paginator import (
    DescribeCertificatesPaginator,
    DescribeConnectionsPaginator,
    DescribeEndpointTypesPaginator,
    DescribeEndpointsPaginator,
    DescribeEventSubscriptionsPaginator,
    DescribeEventsPaginator,
    DescribeOrderableReplicationInstancesPaginator,
    DescribeReplicationInstancesPaginator,
    DescribeReplicationSubnetGroupsPaginator,
    DescribeReplicationTaskAssessmentResultsPaginator,
    DescribeReplicationTasksPaginator,
    DescribeSchemasPaginator,
    DescribeTableStatisticsPaginator,
)

client: DatabaseMigrationServiceClient = boto3.client("dms")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
describe_certificates_paginator: DescribeCertificatesPaginator = client.get_paginator("describe_certificates")
describe_connections_paginator: DescribeConnectionsPaginator = client.get_paginator("describe_connections")
describe_endpoint_types_paginator: DescribeEndpointTypesPaginator = client.get_paginator("describe_endpoint_types")
describe_endpoints_paginator: DescribeEndpointsPaginator = client.get_paginator("describe_endpoints")
describe_event_subscriptions_paginator: DescribeEventSubscriptionsPaginator = client.get_paginator("describe_event_subscriptions")
describe_events_paginator: DescribeEventsPaginator = client.get_paginator("describe_events")
describe_orderable_replication_instances_paginator: DescribeOrderableReplicationInstancesPaginator = client.get_paginator("describe_orderable_replication_instances")
describe_replication_instances_paginator: DescribeReplicationInstancesPaginator = client.get_paginator("describe_replication_instances")
describe_replication_subnet_groups_paginator: DescribeReplicationSubnetGroupsPaginator = client.get_paginator("describe_replication_subnet_groups")
describe_replication_task_assessment_results_paginator: DescribeReplicationTaskAssessmentResultsPaginator = client.get_paginator("describe_replication_task_assessment_results")
describe_replication_tasks_paginator: DescribeReplicationTasksPaginator = client.get_paginator("describe_replication_tasks")
describe_schemas_paginator: DescribeSchemasPaginator = client.get_paginator("describe_schemas")
describe_table_statistics_paginator: DescribeTableStatisticsPaginator = client.get_paginator("describe_table_statistics")
```

<a id="waiters-annotations"></a>

### Waiters annotations

`mypy_boto3_dms.waiter` module contains type annotations for all waiters.

```python
from mypy_boto3_dms import DatabaseMigrationServiceClient
from mypy_boto3_dms.waiter import (
    EndpointDeletedWaiter,
    ReplicationInstanceAvailableWaiter,
    ReplicationInstanceDeletedWaiter,
    ReplicationTaskDeletedWaiter,
    ReplicationTaskReadyWaiter,
    ReplicationTaskRunningWaiter,
    ReplicationTaskStoppedWaiter,
    TestConnectionSucceedsWaiter,
)

client: DatabaseMigrationServiceClient = boto3.client("dms")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
endpoint_deleted_waiter: EndpointDeletedWaiter = client.get_waiter("endpoint_deleted")
replication_instance_available_waiter: ReplicationInstanceAvailableWaiter = client.get_waiter("replication_instance_available")
replication_instance_deleted_waiter: ReplicationInstanceDeletedWaiter = client.get_waiter("replication_instance_deleted")
replication_task_deleted_waiter: ReplicationTaskDeletedWaiter = client.get_waiter("replication_task_deleted")
replication_task_ready_waiter: ReplicationTaskReadyWaiter = client.get_waiter("replication_task_ready")
replication_task_running_waiter: ReplicationTaskRunningWaiter = client.get_waiter("replication_task_running")
replication_task_stopped_waiter: ReplicationTaskStoppedWaiter = client.get_waiter("replication_task_stopped")
test_connection_succeeds_waiter: TestConnectionSucceedsWaiter = client.get_waiter("test_connection_succeeds")
```

<a id="literals"></a>

### Literals

`mypy_boto3_dms.literals` module contains literals extracted from shapes that
can be used in user code for type checking.

```python
from mypy_boto3_dms.literals import (
    AuthMechanismValueType,
    AuthTypeValueType,
    CharLengthSemanticsType,
    CompressionTypeValueType,
    DataFormatValueType,
    DatePartitionDelimiterValueType,
    DatePartitionSequenceValueType,
    DescribeCertificatesPaginatorName,
    DescribeConnectionsPaginatorName,
    DescribeEndpointTypesPaginatorName,
    DescribeEndpointsPaginatorName,
    DescribeEventSubscriptionsPaginatorName,
    DescribeEventsPaginatorName,
    DescribeOrderableReplicationInstancesPaginatorName,
    DescribeReplicationInstancesPaginatorName,
    DescribeReplicationSubnetGroupsPaginatorName,
    DescribeReplicationTaskAssessmentResultsPaginatorName,
    DescribeReplicationTasksPaginatorName,
    DescribeSchemasPaginatorName,
    DescribeTableStatisticsPaginatorName,
    DmsSslModeValueType,
    EncodingTypeValueType,
    EncryptionModeValueType,
    EndpointDeletedWaiterName,
    EndpointSettingTypeValueType,
    KafkaSecurityProtocolType,
    MessageFormatValueType,
    MigrationTypeValueType,
    NestingLevelValueType,
    ParquetVersionValueType,
    RefreshSchemasStatusTypeValueType,
    ReleaseStatusValuesType,
    ReloadOptionValueType,
    ReplicationEndpointTypeValueType,
    ReplicationInstanceAvailableWaiterName,
    ReplicationInstanceDeletedWaiterName,
    ReplicationTaskDeletedWaiterName,
    ReplicationTaskReadyWaiterName,
    ReplicationTaskRunningWaiterName,
    ReplicationTaskStoppedWaiterName,
    SafeguardPolicyType,
    SourceTypeType,
    StartReplicationTaskTypeValueType,
    TargetDbTypeType,
    TestConnectionSucceedsWaiterName,
)

def check_value(value: AuthMechanismValueType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_dms.type_defs` module contains structures and shapes assembled to
typed dictionaries for additional type checking.

```python
from mypy_boto3_dms.type_defs import (
    AccountQuotaTypeDef,
    AddTagsToResourceMessageRequestTypeDef,
    ApplyPendingMaintenanceActionMessageRequestTypeDef,
    ApplyPendingMaintenanceActionResponseTypeDef,
    AvailabilityZoneTypeDef,
    CancelReplicationTaskAssessmentRunMessageRequestTypeDef,
    CancelReplicationTaskAssessmentRunResponseTypeDef,
    CertificateTypeDef,
    ConnectionTypeDef,
    CreateEndpointMessageRequestTypeDef,
    CreateEndpointResponseTypeDef,
    CreateEventSubscriptionMessageRequestTypeDef,
    CreateEventSubscriptionResponseTypeDef,
    CreateReplicationInstanceMessageRequestTypeDef,
    CreateReplicationInstanceResponseTypeDef,
    CreateReplicationSubnetGroupMessageRequestTypeDef,
    CreateReplicationSubnetGroupResponseTypeDef,
    CreateReplicationTaskMessageRequestTypeDef,
    CreateReplicationTaskResponseTypeDef,
    DeleteCertificateMessageRequestTypeDef,
    DeleteCertificateResponseTypeDef,
    DeleteConnectionMessageRequestTypeDef,
    DeleteConnectionResponseTypeDef,
    DeleteEndpointMessageRequestTypeDef,
    DeleteEndpointResponseTypeDef,
    DeleteEventSubscriptionMessageRequestTypeDef,
    DeleteEventSubscriptionResponseTypeDef,
    DeleteReplicationInstanceMessageRequestTypeDef,
    DeleteReplicationInstanceResponseTypeDef,
    DeleteReplicationSubnetGroupMessageRequestTypeDef,
    DeleteReplicationTaskAssessmentRunMessageRequestTypeDef,
    DeleteReplicationTaskAssessmentRunResponseTypeDef,
    DeleteReplicationTaskMessageRequestTypeDef,
    DeleteReplicationTaskResponseTypeDef,
    DescribeAccountAttributesResponseTypeDef,
    DescribeApplicableIndividualAssessmentsMessageRequestTypeDef,
    DescribeApplicableIndividualAssessmentsResponseTypeDef,
    DescribeCertificatesMessageRequestTypeDef,
    DescribeCertificatesResponseTypeDef,
    DescribeConnectionsMessageRequestTypeDef,
    DescribeConnectionsResponseTypeDef,
    DescribeEndpointSettingsMessageRequestTypeDef,
    DescribeEndpointSettingsResponseTypeDef,
    DescribeEndpointTypesMessageRequestTypeDef,
    DescribeEndpointTypesResponseTypeDef,
    DescribeEndpointsMessageRequestTypeDef,
    DescribeEndpointsResponseTypeDef,
    DescribeEventCategoriesMessageRequestTypeDef,
    DescribeEventCategoriesResponseTypeDef,
    DescribeEventSubscriptionsMessageRequestTypeDef,
    DescribeEventSubscriptionsResponseTypeDef,
    DescribeEventsMessageRequestTypeDef,
    DescribeEventsResponseTypeDef,
    DescribeOrderableReplicationInstancesMessageRequestTypeDef,
    DescribeOrderableReplicationInstancesResponseTypeDef,
    DescribePendingMaintenanceActionsMessageRequestTypeDef,
    DescribePendingMaintenanceActionsResponseTypeDef,
    DescribeRefreshSchemasStatusMessageRequestTypeDef,
    DescribeRefreshSchemasStatusResponseTypeDef,
    DescribeReplicationInstanceTaskLogsMessageRequestTypeDef,
    DescribeReplicationInstanceTaskLogsResponseTypeDef,
    DescribeReplicationInstancesMessageRequestTypeDef,
    DescribeReplicationInstancesResponseTypeDef,
    DescribeReplicationSubnetGroupsMessageRequestTypeDef,
    DescribeReplicationSubnetGroupsResponseTypeDef,
    DescribeReplicationTaskAssessmentResultsMessageRequestTypeDef,
    DescribeReplicationTaskAssessmentResultsResponseTypeDef,
    DescribeReplicationTaskAssessmentRunsMessageRequestTypeDef,
    DescribeReplicationTaskAssessmentRunsResponseTypeDef,
    DescribeReplicationTaskIndividualAssessmentsMessageRequestTypeDef,
    DescribeReplicationTaskIndividualAssessmentsResponseTypeDef,
    DescribeReplicationTasksMessageRequestTypeDef,
    DescribeReplicationTasksResponseTypeDef,
    DescribeSchemasMessageRequestTypeDef,
    DescribeSchemasResponseTypeDef,
    DescribeTableStatisticsMessageRequestTypeDef,
    DescribeTableStatisticsResponseTypeDef,
    DmsTransferSettingsTypeDef,
    DocDbSettingsTypeDef,
    DynamoDbSettingsTypeDef,
    ElasticsearchSettingsTypeDef,
    EndpointSettingTypeDef,
    EndpointTypeDef,
    EventCategoryGroupTypeDef,
    EventSubscriptionTypeDef,
    EventTypeDef,
    FilterTypeDef,
    IBMDb2SettingsTypeDef,
    ImportCertificateMessageRequestTypeDef,
    ImportCertificateResponseTypeDef,
    KafkaSettingsTypeDef,
    KinesisSettingsTypeDef,
    ListTagsForResourceMessageRequestTypeDef,
    ListTagsForResourceResponseTypeDef,
    MicrosoftSQLServerSettingsTypeDef,
    ModifyEndpointMessageRequestTypeDef,
    ModifyEndpointResponseTypeDef,
    ModifyEventSubscriptionMessageRequestTypeDef,
    ModifyEventSubscriptionResponseTypeDef,
    ModifyReplicationInstanceMessageRequestTypeDef,
    ModifyReplicationInstanceResponseTypeDef,
    ModifyReplicationSubnetGroupMessageRequestTypeDef,
    ModifyReplicationSubnetGroupResponseTypeDef,
    ModifyReplicationTaskMessageRequestTypeDef,
    ModifyReplicationTaskResponseTypeDef,
    MongoDbSettingsTypeDef,
    MoveReplicationTaskMessageRequestTypeDef,
    MoveReplicationTaskResponseTypeDef,
    MySQLSettingsTypeDef,
    NeptuneSettingsTypeDef,
    OracleSettingsTypeDef,
    OrderableReplicationInstanceTypeDef,
    PaginatorConfigTypeDef,
    PendingMaintenanceActionTypeDef,
    PostgreSQLSettingsTypeDef,
    RebootReplicationInstanceMessageRequestTypeDef,
    RebootReplicationInstanceResponseTypeDef,
    RedshiftSettingsTypeDef,
    RefreshSchemasMessageRequestTypeDef,
    RefreshSchemasResponseTypeDef,
    RefreshSchemasStatusTypeDef,
    ReloadTablesMessageRequestTypeDef,
    ReloadTablesResponseTypeDef,
    RemoveTagsFromResourceMessageRequestTypeDef,
    ReplicationInstanceTaskLogTypeDef,
    ReplicationInstanceTypeDef,
    ReplicationPendingModifiedValuesTypeDef,
    ReplicationSubnetGroupTypeDef,
    ReplicationTaskAssessmentResultTypeDef,
    ReplicationTaskAssessmentRunProgressTypeDef,
    ReplicationTaskAssessmentRunTypeDef,
    ReplicationTaskIndividualAssessmentTypeDef,
    ReplicationTaskStatsTypeDef,
    ReplicationTaskTypeDef,
    ResourcePendingMaintenanceActionsTypeDef,
    ResponseMetadataTypeDef,
    S3SettingsTypeDef,
    StartReplicationTaskAssessmentMessageRequestTypeDef,
    StartReplicationTaskAssessmentResponseTypeDef,
    StartReplicationTaskAssessmentRunMessageRequestTypeDef,
    StartReplicationTaskAssessmentRunResponseTypeDef,
    StartReplicationTaskMessageRequestTypeDef,
    StartReplicationTaskResponseTypeDef,
    StopReplicationTaskMessageRequestTypeDef,
    StopReplicationTaskResponseTypeDef,
    SubnetTypeDef,
    SupportedEndpointTypeTypeDef,
    SybaseSettingsTypeDef,
    TableStatisticsTypeDef,
    TableToReloadTypeDef,
    TagTypeDef,
    TestConnectionMessageRequestTypeDef,
    TestConnectionResponseTypeDef,
    VpcSecurityGroupMembershipTypeDef,
    WaiterConfigTypeDef,
)

def get_structure() -> AccountQuotaTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`mypy-boto3-dms` version is the same as related `boto3` version and follows
[PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[mypy-boto3-dms docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_dms/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
